@@ -50,8 +50,6 @@
 
 #include <KWindowSystem/KWindowSystem>
 #include <KWindowSystem/NETWM>
-#include <KF5/KScreen/kscreen/output.h>
-#include <KF5/KScreen/kscreen/configmonitor.h>
 
 #include <QGSettings>
 // Turn on this to show the time required to load each plugin during startup
@@ -217,25 +215,19 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
          */
     connect(QApplication::desktop(), &QDesktopWidget::resized, this, &UKUIPanel::ensureVisible);
     connect(QApplication::desktop(), &QDesktopWidget::screenCountChanged, this, &UKUIPanel::ensureVisible);
+    connect(qApp, &QApplication::primaryScreenChanged, this, &UKUIPanel::ensureVisible);
 
     // connecting to QDesktopWidget::workAreaResized shouldn't be necessary,
     // as we've already connceted to QDesktopWidget::resized, but it actually
     connect(QApplication::desktop(), &QDesktopWidget::workAreaResized,
             this, &UKUIPanel::ensureVisible);
-    //适配KScreen后，分辨率改变的信号无法获取，需要从SettingsDaemon拿分辨率改变的信号
+    //从SettingsDaemon拿分辨率改变的信号
     QDBusConnection::sessionBus().connect(QString(USD_SERVICE),
                                           QString(USD_XRANDER_PATH),
                                           QString(USD_XRANDER_INTERFACE),
                                           QString(PRIMARY_CHANGED),
                                           this, SLOT(primaryChangedSlot(int, int, int, int, int)));
 
-    UKUIPanelApplication *a = reinterpret_cast<UKUIPanelApplication*>(qApp);
-    m_primaryScreenGeometry = QGuiApplication::screens().at(0)->geometry();
-    KScreen::GetConfigOperation *op = new KScreen::GetConfigOperation();
-    connect(op, &KScreen::GetConfigOperation::finished, this, [this](KScreen::ConfigOperation *op) {
-        configWatch(op);
-    });
-
     connect(UKUi::Settings::globalSettings(), SIGNAL(settingsChanged()), this, SLOT(update()));
 
     connect(m_standaloneWindows.data(), &WindowNotifier::firstShown, [this] { showPanel(true); });
@@ -337,40 +329,6 @@ UKUIPanel::UKUIPanel(const QString &configGroup, UKUi::Settings *settings, QWidg
 
 }
 
-void UKUIPanel::configWatch(KScreen::ConfigOperation *op)
-{
-    m_config = op->config();
-
-    KScreen::ConfigMonitor::instance()->addConfig(m_config);
-
-//    connect(m_config.data(), &KScreen::Config::primaryOutputChanged,
-//        this, [=](const KScreen::OutputPtr &output){
-//        if (!output.isNull()) {
-//            qDebug() << "primaryOutputChanged:" << output->name() << output->geometry();
-//            m_primaryScreenGeometry = output->geometry();
-//            QRect rect = caculPanelGeometry(output->geometry());
-//            qDebug()<<"primaryOutputChanged  panel rect is"<<rect;
-//            kdk::WindowManager::setGeometry(this->windowHandle(), rect);
-//            realign();
-//        }
-//    });
-    connect(m_config.data(), &KScreen::Config::outputAdded,
-            this, [=](const KScreen::OutputPtr &output){
-        if (!output.isNull()) {
-            KScreen::OutputPtr primary = m_config->primaryOutput();
-            m_primaryScreenGeometry = primary->geometry();
-            qDebug()<<"output added primary geometry is"<<primary->geometry();
-            QRect rect = caculPanelGeometry(primary->geometry());
-            qDebug()<<"output added  panel rect is"<<rect;
-            kdk::WindowManager::setGeometry(this->windowHandle(), rect);
-        }
-    });
-    connect(m_config.data(), &KScreen::Config::outputRemoved,
-            this, [=](){
-       qDebug() << "output removed";
-    });
-}
-
 void UKUIPanel::setPanelHide(bool model)
 {
     if (model) {
@@ -469,7 +427,7 @@ void UKUIPanel::primaryChangedSlot(int x, int y, int w, int h, int r)
         qWarning() << "---------From QGuiApplication " << QGuiApplication::screens().at(0)->geometry();
     }
 
-    m_primaryScreenGeometry = QGuiApplication::screens().at(0)->geometry();
+    m_primaryScreenGeometry = QGuiApplication::primaryScreen()->geometry();
     realign();
 }
 
@@ -659,6 +617,7 @@ QRect UKUIPanel::caculPanelGeometry(QRect primaryscreen)
  */
 void UKUIPanel::setPanelGeometry(bool animate)
 {
+    m_primaryScreenGeometry = QGuiApplication::primaryScreen()->geometry();
     QRect rect = caculPanelGeometry(m_primaryScreenGeometry);
     if (rect != geometry()) {
         setFixedSize(rect.size());
@@ -1282,10 +1241,10 @@ void UKUIPanel::keyChangedSlot(const QString &key) {
 IUKUIPanel::Position UKUIPanel::areaDivid(QPoint globalpos) {
     int x = globalpos.rx();
     int y = globalpos.ry();
-    int x_0 = QApplication::screens().at(0)->geometry().x();
-    int y_0 = QApplication::screens().at(0)->geometry().y();
-    float W = QApplication::screens().at(0)->size().width();
-    float H = QApplication::screens().at(0)->size().height();
+    int x_0 = QApplication::primaryScreen()->geometry().x();
+    int y_0 = QApplication::primaryScreen()->geometry().y();
+    float W = QApplication::primaryScreen()->size().width();
+    float H = QApplication::primaryScreen()->size().height();
     float slope = H / W;
     if ((x - x_0 < 100 || x -x_0 > W - 100) && (y - y_0 > H - 100 || y - y_0 < 100)) return m_position;
     if ((y - y_0) > (int)((x - x_0) * slope) && (y - y_0) > (int)(H - (x - x_0) * slope)) return PositionBottom;
@@ -1308,7 +1267,7 @@ void UKUIPanel::mouseMoveEvent(QMouseEvent* event)
         else m_moveLock = 1;
     }
     if (!m_moveLock) {
-        int panel_h = QApplication::screens().at(0)->size().height() - event->globalPos().ry();
+        int panel_h = QApplication::primaryScreen()->size().height() - event->globalPos().ry();
         int icon_size = panel_h*0.695652174;
         setCursor(Qt::SizeVerCursor);
         if (panel_h <= PANEL_SIZE_LARGE && panel_h >= PANEL_SIZE_SMALL) {
