@@ -41,8 +41,6 @@
 #include "iukuipanel.h"
 #include "ukuipanelglobals.h"
 #include "contextmenu.h"
-#include <KF5/KScreen/kscreen/config.h>
-#include <KF5/KScreen/kscreen/getconfigoperation.h>
 
 
 class QMenu;
@@ -89,7 +87,6 @@ class UKUI_PANEL_API UKUIPanel : public QFrame, public IUKUIPanel
     friend class PanelPluginsModel;
 
 public:
-    void configWatch(KScreen::ConfigOperation *op);
     QRect m_primaryScreenGeometry;
     /**
      * @brief Stores how the panel should be aligned. Obviously, this applies
@@ -416,7 +413,6 @@ private Q_SLOTS:
     QStringList pluginDesktopDirs();
 
 private:
-    KScreen::ConfigPtr m_config;
     bool m_isWaylandEnv;
     /**
      * @brief The UKUIPanelLayout of this panel. All the Plugins will be added
